<?php

require_once "phpfspot_cfg.php";
require_once "phpfspot_db.php";
require_once "phpfspot_tmpl.php";

class PHPFSPOT {

   var $cfg;
   var $db;
   var $tmpl;
   var $tags;
   var $avail_tags;
   var $current_tags;

   public function __construct()
   {
      $this->cfg = new PHPFSPOT_CFG;

      $this->db = new PHPFSPOT_DB(&$this, $this->cfg->db);
      $this->tmpl = new PHPFSPOT_TMPL($this);

      $this->get_tags();

   } // __construct()

   public function __destruct()
   {

   } // __destruct()

   public function show()
   {
      $this->tmpl->assign('page_title', $this->cfg->page_title);
      $this->tmpl->show("index.tpl");

   } // show()

   private function get_tags()
   {
      $this->avail_tags = Array();
      $count = 0;
   
      $result = $this->db->db_query("
         SELECT id,name
         FROM tags
         ORDER BY sort_priority ASC
      ");
      
      while($row = $this->db->db_fetch_object($result)) {

         $tag_id = $row['id'];
         $tag_name = $row['name'];

         $this->tags[$tag_id] = $tag_name; 
         $this->avail_tags[$count] = $tag_id;

         $count++;

      }

   } // get_tags()

   public function get_photo_details($idx)
   {
      $result = $this->db->db_query("
         SELECT *
         FROM photos
         WHERE id='". $idx ."'
      ");
      
      return $this->db->db_fetch_object($result);

   } // get_photo_details

   public function translate_path($path, $width = 0)
   {  
      return str_replace($this->cfg->path_replace_from, $this->cfg->path_replace_to, $path);

   } // translate_path

   public function showPhoto($photo)
   {
      $all_photos = $this->getAllTagPhotos();

      foreach($all_photos as $all_photo) {
         
         if($get_next) {
            $next_img = $all_photo;
            break;
         }

         if($all_photo == $photo) {
            $get_next = 1;
         }
         else {
            $previous_img = $all_photo;
         }
      }


      $details = $this->get_photo_details($photo);

      $this->tmpl->assign('image_name', $details['name']);
      $this->tmpl->assign('image_url', 'phpfspot_img.php?idx='. $photo ."&amp;width=". $this->cfg->photo_width);

      if($previous_img) {
         $this->tmpl->assign('previous_url', "javascript:showImage(". $previous_img .");");
      }

      if($next_img) {
         $this->tmpl->assign('next_url', "javascript:showImage(". $next_img .");");
      }

      $this->tmpl->show("single_photo.tpl");

   } // showPhoto()

   public function getAvailableTags()
   {
      foreach($this->avail_tags as $tag)
      {
         if(isset($_SESSION['selected_tags']) && in_array($tag, $_SESSION['selected_tags']))
            continue;

         // return all available (= not selected) tags
         print "<a href=\"javascript:Tags('add', ". $tag .");\">". $this->tags[$tag] ."</a>&nbsp;";

      }

   } // getAvailableTags()

   public function getSelectedTags()
   {
      foreach($this->avail_tags as $tag)
      {
         // return all selected tags
         if(isset($_SESSION['selected_tags']) && in_array($tag, $_SESSION['selected_tags'])) {
            print "<a href=\"javascript:Tags('del', ". $tag .");\">". $this->tags[$tag] ."</a>&nbsp;";
         }

      }

   } // getSelectedTags()

   public function addTag($tag)
   {
      if(!isset($_SESSION['selected_tags']))
         $_SESSION['selected_tags'] = Array();

      array_push($_SESSION['selected_tags'], $tag);
   
   } // addTag()

   public function delTag($tag)
   {
      if(isset($_SESSION['selected_tags'])) {
         $key = array_search($tag, $_SESSION['selected_tags']);
         unset($_SESSION['selected_tags'][$key]);
      }

   } // delTag()

   public function resetTags()
   {
      unset($_SESSION['selected_tags']);

   } // resetTags()

   public function getAllTagPhotos()
   {  
      $tagged_photos = Array();

      if(isset($_SESSION['selected_tags'])) {
         $selected = "";
         foreach($_SESSION['selected_tags'] as $tag)
            $selected.= $tag .",";
         $selected = substr($selected, 0, strlen($selected)-1);
         $result = $this->db->db_query("
            SELECT DISTINCT photo_id
               FROM photo_tags pt
            INNER JOIN photos p
               ON p.id=pt.photo_id
            WHERE pt.tag_id IN (". $selected .")
            ORDER BY p.time ASC
         ");
      }
      else {
         $result = $this->db->db_query("
            SELECT DISTINCT photo_id
               FROM photo_tags pt
            INNER JOIN photos p
               ON p.id=pt.photo_id
            ORDER BY p.time ASC
         ");
      }

      while($row = $this->db->db_fetch_object($result)) {
         array_push($tagged_photos, $row['photo_id']);
      }

      return $tagged_photos;

   } // getAllTagPhotos()

   public function showPhotoIndex()
   {
      $photos = $this->getAllTagPhotos();
      $count = count($photos);

      $rows = 0;
      $cols = 0;
      $images[$rows] = Array();

      for($i = 0; $i < $count; $i++) {

         $images[$rows][$cols] = $photos[$i];

         if($cols == $this->cfg->thumbs_per_row-1) {
            $cols = 0;
            $rows++;
            $images[$rows] = Array();
         }
         else {
            $cols++;
         }
      } 

      // +1 for for smarty's selection iteration
      $rows++;

         //$images.= "<img src=\"phpfspot_img.php?idx=". $photo ."&amp;width=". $this->cfg->thumb_width ."\" /><br />\n";

      $this->tmpl->assign('count', $count);
      $this->tmpl->assign('width', $this->cfg->thumb_width);
      $this->tmpl->assign('images', $images);
      $this->tmpl->assign('rows', $rows);
      $this->tmpl->assign('columns', $this->cfg->thumbs_per_row);
      $this->tmpl->show("photo_index.tpl");


   } // showPhotoIndex()

   public function showBubbleDetails($photo, $direction)
   {
      if($direction == "up")
         $direction = "bubbleimg_up";
      else
         $direction = "bubbleimg_down";

      $details = $this->get_photo_details($photo);

      $image_url = "phpfspot_img.php?idx=". $photo ."&amp;width=200";

      $filesize = filesize($this->translate_path($details['directory_path'])  ."/". $details['name']);
      $filesize = rand($filesize/1024, 2);

      $img = getimagesize($this->translate_path($details['directory_path'])  ."/". $details['name']);

      $this->tmpl->assign('file_size', $filesize);
      $this->tmpl->assign('width', $img[0]);
      $this->tmpl->assign('height', $img[1]);
      $this->tmpl->assign('file_name', $details['name']);
      $this->tmpl->assign('image_id', $direction);
      $this->tmpl->assign('image_url', $image_url);
      $this->tmpl->show("bubble_details.tpl");

   } // showBubbleDetails()

   public function showCredits()
   {
      $this->tmpl->assign('version', $this->cfg->version);
      $this->tmpl->assign('product', $this->cfg->product);
      $this->tmpl->show("credits.tpl");

   } // showCredits()

}

?>
